// gl.cpp: implementation of the CGL class.
//
//////////////////////////////////////////////////////////////////////

#include "glstdafx.h"
#include "gl.h"


using namespace std;

int CGL::n;
GLfloat CGL::m_fLetterSize;
GLfloat CGL::m_fAspectRatio;
GLsizei CGL::m_siWidth,
		CGL::m_siHeight;


GLboolean CGL::m_bAllControlsRemoved=false;

GLubyte ** CGL::m_pLetters;

CONTROLS_LIST CGL::m_lstControls;
CONTROLS_LIST::iterator CGL::m_iSelectedControl;
PFNTIMERPROC * CGL::m_pfnOnTimer=NULL;
PFNTIMERPROC * CGL::m_pfnOnRender=NULL;
PFNSPECIALKEYPROC * CGL::m_pfnOnSpecialKey=NULL;
PFNMOUSEPROC * CGL::m_pfnOnMouse=NULL;
PFNKEYBOARDPROC* CGL::m_pfnOnKeyboard=NULL;
PFNRESIZEPROC* CGL::m_pfnOnResize=NULL;
GLint   CGL::m_nTimerDelay=50;
//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CGL::CGL(char * WindowTitle)
{
	glutInitDisplayMode(GLUT_MULTISAMPLE| GLUT_DOUBLE | GLUT_RGBA | GLUT_DEPTH |GLUT_STENCIL);
	glEnable(GLUT_MULTISAMPLE);
	glutCreateWindow(WindowTitle);
	glutDisplayFunc(Render);
	glutReshapeFunc(OnResize);
	glutSpecialFunc(OnSpecialKey);
	glutKeyboardFunc(OnKeyboard);
	glutTimerFunc(m_nTimerDelay,OnTimer,0);
	glutMouseFunc(OnMouse);
	glEnable(GL_DEPTH_TEST);
	glEnable(GL_LIGHTING);
	glEnableClientState(GL_COLOR_ARRAY);
	glEnableClientState(GL_VERTEX_ARRAY);
	glEnableClientState(GL_NORMAL_ARRAY);
	glEnable(GL_CULL_FACE);
	glEnable(GL_COLOR_MATERIAL);
	//glPolygonMode(GL_FRONT,GL_LINE);
	InitFont();
		


	}

CGL::~CGL()
{

}




void CGL::Render()
{
	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT |GL_STENCIL_BUFFER_BIT);
	glMatrixMode(GL_MODELVIEW);
	glLoadIdentity();
	if (m_pfnOnRender) m_pfnOnRender();

	glPushAttrib(GL_ENABLE_BIT|GL_COLOR_BUFFER_BIT);
	glDisable(GL_LIGHTING);
	glDisable(GL_DEPTH_TEST);

	glMatrixMode(GL_MODELVIEW);
	glLoadIdentity();

	

	glEnable(GL_BLEND);
	glBlendFunc(GL_SRC_ALPHA,GL_ONE_MINUS_SRC_ALPHA);
	GLfloat fLastColor[4];
	glGetFloatv(GL_CURRENT_COLOR,fLastColor);
	
	CONTROLS_LIST::iterator iList;
	for (iList=m_lstControls.begin();iList!=m_lstControls.end();iList++)
	{

		if ((CGLControl::GetSelected()) ==(*iList))
			glColor4f(1.0,1.0,0.0,0.5);
		else
			glColor4f(0.0,1.0,0.0,0.5);
		(*iList)->Draw();
	}
                           
	glPopAttrib();

	glColor4fv(fLastColor);
	glFlush();
	glutSwapBuffers();
}

void CGL::OnTimer(GLint value)
{
	if (m_pfnOnTimer) m_pfnOnTimer(value);
	glutPostRedisplay();
	glutTimerFunc(m_nTimerDelay, OnTimer, 1);

}

void CGL::OnResize(GLsizei w, GLsizei h)
{
	if (h == 0)
		h = 1;
	glViewport(0, 0, w, h);
	glMatrixMode(GL_PROJECTION);
	glLoadIdentity();
	m_fAspectRatio = (GLfloat)w / (GLfloat)h;

	m_siWidth=w;
	m_siHeight=h;


	GLfloat zn=1.0f,zf=FLT_MAX;
	GLfloat l=-1.0f,
		r=1.0f,
		b=-1.0f,
		t=1.0f;
	
	if (w>=h)	
	{
		r=r*m_fAspectRatio;
		l=-r;
	}
	else
	{
		t=t/m_fAspectRatio;
		b=-t;
	}

	GLfloat mat[]={
		2*zn/(r-l)   ,0            ,(l+r)/(r-l)     ,0,
		0            ,2*zn/(t-b)   ,(t+b)/(t-b)     ,0,
		0			 , 0			 ,zn*zf/(zn-zf)    ,zn*zf/(zn-zf),
		0            ,0            ,  -1				 ,0,


	};

	glLoadMatrixf(mat);

	glMatrixMode(GL_MODELVIEW);
	//glLoadIdentity();

	//   
	if (m_siWidth>m_siHeight) m_fLetterSize=2.0/(GLfloat)m_siHeight;
	else m_fLetterSize=2.0/(GLfloat)m_siWidth;
	m_fLetterSize*=8.0;
	if (m_pfnOnResize) m_pfnOnResize(w,h);
}


void CGL::SetPointLight(GLint p_nIndex,const CGLVector3& p_fPosition,const CGLColor& p_fColor)
{
	GLfloat afPosition[]={p_fPosition.x,p_fPosition.y,p_fPosition.z,0.0f};
	GLfloat afColor[]={p_fColor.r,p_fColor.g,p_fColor.b,p_fColor.a};
	glLightfv(p_nIndex,GL_DIFFUSE,afColor);
	glLightfv(p_nIndex,GL_SPECULAR,afColor);
	glLightfv(p_nIndex,GL_POSITION,afPosition);
	glLightf(p_nIndex,GL_SPOT_CUTOFF,180.0f);
	glEnable(p_nIndex);
}

void CGL::SetSpotLight(GLint p_nIndex,const CGLVector3& p_fPosition,const CGLVector3& p_fDirection,
					   const CGLColor& p_fColor)
{
	GLfloat afPosition[]={p_fPosition.x,p_fPosition.y,p_fPosition.z,1.0f},
		afDirection[]={p_fDirection.x,p_fDirection.y,p_fDirection.z},
		afColor[]={p_fColor.r,p_fColor.g,p_fColor.b,p_fColor.a};
	
	glLightfv(p_nIndex,GL_DIFFUSE,afColor);
	glLightfv(p_nIndex,GL_SPECULAR,afColor);
	glLightfv(p_nIndex,GL_POSITION,afPosition);
	glLightfv(p_nIndex,GL_SPOT_DIRECTION,afDirection);

	glLightf(p_nIndex,GL_SPOT_CUTOFF,60.0f);
	glLightf(p_nIndex,GL_SPOT_EXPONENT,10.0f);
		glEnable(p_nIndex);
}

void CGL::OnSpecialKey(GLint p_nKey,GLint p_nx,GLint p_ny)
{

	if (!m_lstControls.empty())(*m_iSelectedControl)->OnSpecialKey(p_nKey,p_nx,p_ny);
	if (m_pfnOnSpecialKey) m_pfnOnSpecialKey(p_nKey,p_nx,p_ny);
}

void CGL::OnKeyboard(unsigned char p_chKey,GLint p_nx,GLint p_ny)
{
	char chKey=(char)p_chKey;
	switch (chKey)
	{
		
	case '	'://
		if (!m_lstControls.empty())
		{
			m_iSelectedControl++;
			if (m_iSelectedControl==m_lstControls.end())
				m_iSelectedControl=m_lstControls.begin();		
			(*m_iSelectedControl)->SetSelected();
		}
		break;
	default:
		if (!m_lstControls.empty())
		{
			(*m_iSelectedControl)->OnKeyboard(chKey,p_nx,p_ny);

		}
		if (m_bAllControlsRemoved) m_bAllControlsRemoved=false;
		if (m_pfnOnKeyboard) m_pfnOnKeyboard((char )p_chKey,p_nx,p_ny);
		break;
	}
}
void CGL::SetMaterial(const CGLColor & p_Color,GLfloat p_fPower)
{
	glMaterialfv(GL_FRONT,GL_AMBIENT_AND_DIFFUSE,(float *)&p_Color);
}


GLboolean CGL::AddControl(const CGLControl* p_pControl)
{
	m_lstControls.push_back((CGLControl*)p_pControl);
	m_iSelectedControl=m_lstControls.begin();
	return 1;
}

void CGL::RemoveAllControls(void)
{
	CONTROLS_LIST::iterator iList;
	for (iList=m_lstControls.begin();iList!=m_lstControls.end();iList++)
	{
		delete (*iList);
	}
	m_lstControls.clear();
	m_bAllControlsRemoved=true;
	m_iSelectedControl=NULL;
}

void CGL::OnMouse(GLint p_nButton,GLint p_nState,GLint p_nx,GLint p_ny)
{
	GLfloat fx,fy;
	GLint ncx=m_siWidth/2,ncy=m_siHeight/2;// 
	GLint nDivider=__min(ncx,ncy);
	fx=(GLfloat)(p_nx-ncx)/(GLfloat)nDivider;
	fy=-(GLfloat)(p_ny-ncy)/(GLfloat)nDivider;
	CONTROLS_LIST::iterator iList;
	CGLControl* p;
	for (iList=m_lstControls.begin();iList!=m_lstControls.end();iList++)
	{
		p=(*iList);
		p->OnMouse(p_nButton,p_nState,fx,fy);
		if (m_bAllControlsRemoved) { m_bAllControlsRemoved=false;break;}
	}
}

void CGL::DrawText(GLfloat p_nx,GLfloat p_ny, GLfloat p_nWidth, GLfloat p_nHeight,const char * str,GLint p_nStringLength)
{
	glPushAttrib(GL_ENABLE_BIT);
	glDisable(GL_DEPTH_TEST);
	GLint n,
		nFirst=0,nEnd;//   

	GLfloat fx=0,fy;

	n=0;fy=-m_fLetterSize;
	while (str[n])
	{

		nEnd=nFirst+int((p_nWidth)/m_fLetterSize);
		if (nEnd<p_nStringLength)
		{
			n=nEnd;
			while ((str[n]!=' ')&&(n>0)) n--;
			if (n>nFirst) nEnd=n;
			
		}
		else	
		{
			nEnd=p_nStringLength;
		}


		for (n=nFirst;n<nEnd;n++)
		{
			glRasterPos3f(p_nx+fx,p_ny+fy,-1.0);//,1.0f);
			glDrawPixels(8,8,GL_GREEN,GL_UNSIGNED_BYTE,(const GLvoid *)*(m_pLetters+str[n]));				
			fx+=m_fLetterSize;
		}
		if (str[nEnd]==' ') nEnd++;
		nFirst=nEnd;
		fy-=m_fLetterSize;
		if (fabs(fy)>p_nHeight) break;
		fx=0;
		
	}
	glPopAttrib();
}


void CGL::InitFont(void)
{
	GLint n;
	static GLubyte * Mass[256];
	m_pLetters=Mass;
	m_pLetters+=-CHAR_MIN;
	static GLubyte abyAPixels[]={
		//A
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};

	static GLubyte abyBPixels[]={
		//B
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyCPixels[]={
		//C
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyDPixels[]={
		//D
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyEPixels[]={
		//E
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyFPixels[]={
		//F
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyGPixels[]={
		//G
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyHPixels[]={
		//H
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyIPixels[]={
		//I
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyJPixels[]={
		//J
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyKPixels[]={
		//K
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0xff,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyLPixels[]={
		//L
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyMPixels[]={
		//M
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0xff,0xff,0x00,0xff,0x00,
		0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyNPixels[]={
		//N
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0xff,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0xff,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyOPixels[]={
		//O
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyPPixels[]={
		//P
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyQPixels[]={
		//Q
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
		0x00,0x00,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRPixels[]={
		//R
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abySPixels[]={
		//S
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyTPixels[]={
		//T
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyUPixels[]={
		//U
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyVPixels[]={
		//V
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,
		0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyWPixels[]={
		//W
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0x00,0x00,0xff,0x00,0x00,
		0x00,0xff,0x00,0xff,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyXPixels[]={
		//X
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0x00,0x00,0xff,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
		0x00,0x00,0xff,0x00,0x00,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyYPixels[]={
		//Y
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
		0x00,0x00,0xff,0x00,0x00,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyZPixels[]={
		//Z
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,



		////////////////////////////////////////
		//  
		////////////////////////////////////////
	};
	static GLubyte abyaPixels[]={
		//a
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,

	};
	static GLubyte abybPixels[]={
		//b
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abycPixels[]={
		//c
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abydPixels[]={
		//d
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyePixels[]={
		//e
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyfPixels[]={
		//f
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abygPixels[]={
		//g
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyhPixels[]={
		//h
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyiPixels[]={
		//i
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyjPixels[]={
		//j
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
	};
	static GLubyte abykPixels[]={
		//k
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abylPixels[]={
		//l
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abymPixels[]={
		//m
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0xff,0x00,0xff,0x00,0x00,
		0x00,0xff,0x00,0xff,0x00,0xff,0x00,0x00,
		0x00,0xff,0x00,0xff,0x00,0xff,0x00,0x00,
		0x00,0xff,0x00,0xff,0x00,0xff,0x00,0x00,
		0x00,0xff,0xff,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abynPixels[]={
		//n
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyoPixels[]={
		//o
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abypPixels[]={
		//p
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyqPixels[]={
		//q
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyrPixels[]={
		//r
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abysPixels[]={
		//s
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abytPixels[]={
		//t
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyuPixels[]={
		//u
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyvPixels[]={
		//v
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,
		0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abywPixels[]={
		//w
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0x00,0x00,0xff,0x00,0x00,
		0x00,0xff,0x00,0xff,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyxPixels[]={
		//x
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0x00,0x00,0xff,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
		0x00,0x00,0xff,0x00,0x00,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyyPixels[]={
		//y
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyzPixels[]={
		//z
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};

	///////////////////////////////////////////
	//Russian
	///////////////////////////////////////////
	static GLubyte *abyRUSAPixels=abyAPixels;
	static GLubyte abyRUSBPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte *abyRUSVPixels=abyBPixels;
	static GLubyte abyRUSGPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSDPixels[]={
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0xff,0x00,0x00,0xff,0x00,0x00,
		0x00,0x00,0xff,0x00,0x00,0xff,0x00,0x00,
		0x00,0x00,0xff,0x00,0x00,0xff,0x00,0x00,
		0x00,0x00,0xff,0x00,0x00,0xff,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};

	static GLubyte *abyRUSEPixels=abyEPixels;
	static GLubyte abyRUSYOPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0xff,0x00,0x00,0xff,0x00,0x00,
	};
	static GLubyte abyRUSJPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0x00,0xff,0x00,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
		0x00,0x00,0xff,0x00,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSZPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00f,0x00,0xff,0x00,
		0x00,0x00,0x00,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSIPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0xff,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSIYPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0xff,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
	};
	static GLubyte *abyRUSKPixels=abyKPixels;
	static GLubyte abyRUSLPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0xff,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0xff,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte *abyRUSMPixels=abyMPixels;
	static GLubyte *abyRUSNPixels=abyHPixels;
	static GLubyte *abyRUSOPixels=abyOPixels;
	static GLubyte abyRUSPPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte *abyRUSRPixels=abyPPixels;
	static GLubyte *abyRUSSPixels=abyCPixels;
	static GLubyte *abyRUSTPixels=abyTPixels;
	static GLubyte abyRUSUPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSFPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte *abyRUSHPixels=abyXPixels;
	static GLubyte abyRUSCPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSCHPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSSHPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};

	static GLubyte abyRUSSHJPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSTVZNPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSbIPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSMZNPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSE2Pixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSYUPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0xff,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0xff,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0xff,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSYAPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0xff,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};




	///////////////////////////////////////////
	//  
	///////////////////////////////////////////


	static GLubyte *abyRUSaPixels=abyaPixels;
	static GLubyte abyRUSbPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSvPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSgPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSdPixels[]={
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0xff,0x00,0x00,0xff,0x00,0x00,
		0x00,0x00,0xff,0x00,0x00,0xff,0x00,0x00,
		0x00,0x00,0xff,0x00,0x00,0xff,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};

	static GLubyte *abyRUSePixels=abyePixels;
	static GLubyte abyRUSyoPixels[]={
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0x00,0x00,0xff,0x00,0x00,
	};
	static GLubyte abyRUSjPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0x00,0xff,0x00,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
		0x00,0x00,0xff,0x00,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSzPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSiPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0xff,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSiyPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0xff,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
	};
	static GLubyte *abyRUSkPixels=abykPixels;
	static GLubyte abyRUSlPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0xff,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSmPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0xff,0xff,0x00,0xff,0x00,
		0x00,0x00,0xff,0x00,0x00,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSnPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte *abyRUSoPixels=abyoPixels;
	static GLubyte abyRUSpPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte *abyRUSrPixels=abypPixels;
	static GLubyte *abyRUSsPixels=abycPixels;
	static GLubyte abyRUStPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSuPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSfPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte *abyRUShPixels=abyxPixels;
	static GLubyte abyRUScPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSchPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSshPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};

	static GLubyte abyRUSshjPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUStvznPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSbiPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSmznPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSe2Pixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSyuPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0xff,0xff,0x00,0x00,
		0x00,0xff,0x00,0xff,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0xff,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};
	static GLubyte abyRUSyaPixels[]={
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	};

	static GLubyte abyPointPixels[]={
		//.
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		};
	static GLubyte abyCommaPixels[]={
		//.
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		};
	static GLubyte abySemicolonPixels[]={
		//.
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		};
	static GLubyte abyColonPixels[]={
		//.
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		};

	static GLubyte abyDashPixels[]={
		//.
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		};

	static GLubyte abyApostrophePixels[]={
		//.
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		};

	static GLubyte abyLessPixels[]={
		//.
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		};
	static GLubyte abyGreaterPixels[]={
		//.
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		};
	static GLubyte abyEqualPixels[]={
		//.
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		};

	///////////////////////////////////////////
	//
	///////////////////////////////////////////
	static GLubyte abyZeroPixels[]={
		//Space bar
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0xff,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0xff,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0xff,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0xff,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		};
	static GLubyte abyOnePixels[]={
		//Space bar
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		};
	static GLubyte abyTwoPixels[]={
		//Space bar
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		};
	static GLubyte abyThreePixels[]={
		//Space bar
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		};
	static GLubyte abyFourPixels[]={
		//Space bar
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		};
	static GLubyte abyFivePixels[]={
		//Space bar
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		};
	static GLubyte abySixPixels[]={
		//Space bar
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		};
	static GLubyte abySevenPixels[]={
		//Space bar
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		};
	static GLubyte abyEightPixels[]={
		//Space bar
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		};
	static GLubyte abyNinePixels[]={
		//Space bar
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		};
	static GLubyte abySpacePixels[]={
		//Space bar
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		};

	static GLubyte abyPlusPixels[]={
		//Space bar
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		};
	static GLubyte abyMultiplyPixels[]={
		//Space bar
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0xff,0x00,0xff,0x00,0xff,0x00,
		0x00,0x00,0x00,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0xff,0xff,0xff,0xff,0xff,0x00,
		0x00,0x00,0x00,0xff,0xff,0xff,0x00,0x00,
		0x00,0x00,0xff,0x00,0xff,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		};
	static GLubyte abyDividerPixels[]={
		//Space bar
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
		0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
		};

	for (n=CHAR_MIN;n<=CHAR_MAX;n++)
		m_pLetters[n]=abySpacePixels;

	m_pLetters['A']=abyAPixels;
	m_pLetters['B']=abyBPixels;
	m_pLetters['C']=abyCPixels;
	m_pLetters['D']=abyDPixels;
	m_pLetters['E']=abyEPixels;
	m_pLetters['F']=abyFPixels;
	m_pLetters['G']=abyGPixels;
	m_pLetters['H']=abyHPixels;
	m_pLetters['I']=abyIPixels;
	m_pLetters['J']=abyJPixels;
	m_pLetters['K']=abyKPixels;
	m_pLetters['L']=abyLPixels;
	m_pLetters['M']=abyMPixels;
	m_pLetters['N']=abyNPixels;
	m_pLetters['O']=abyOPixels;
	m_pLetters['P']=abyPPixels;
	m_pLetters['Q']=abyQPixels;
	m_pLetters['R']=abyRPixels;
	m_pLetters['S']=abySPixels;
	m_pLetters['T']=abyTPixels;
	m_pLetters['U']=abyUPixels;
	m_pLetters['V']=abyVPixels;
	m_pLetters['W']=abyWPixels;
	m_pLetters['X']=abyXPixels;
	m_pLetters['Y']=abyYPixels;
	m_pLetters['Z']=abyZPixels;

	m_pLetters['a']=abyaPixels;
	m_pLetters['b']=abybPixels;
	m_pLetters['c']=abycPixels;
	m_pLetters['d']=abydPixels;
	m_pLetters['e']=abyePixels;
	m_pLetters['f']=abyfPixels;
	m_pLetters['g']=abygPixels;
	m_pLetters['h']=abyhPixels;
	m_pLetters['i']=abyiPixels;
	m_pLetters['j']=abyjPixels;
	m_pLetters['k']=abykPixels;
	m_pLetters['l']=abylPixels;
	m_pLetters['m']=abymPixels;
	m_pLetters['n']=abynPixels;
	m_pLetters['o']=abyoPixels;
	m_pLetters['p']=abypPixels;
	m_pLetters['q']=abyqPixels;
	m_pLetters['r']=abyrPixels;
	m_pLetters['s']=abysPixels;
	m_pLetters['t']=abytPixels;
	m_pLetters['u']=abyuPixels;
	m_pLetters['v']=abyvPixels;
	m_pLetters['w']=abywPixels;
	m_pLetters['x']=abyxPixels;
	m_pLetters['y']=abyyPixels;
	m_pLetters['z']=abyzPixels;
	m_pLetters[' ']=abySpacePixels;


	//Russian
	m_pLetters['']=abyRUSAPixels;
	m_pLetters['']=abyRUSBPixels;
	m_pLetters['']=abyRUSVPixels;
	m_pLetters['']=abyRUSGPixels;
	m_pLetters['']=abyRUSDPixels;
	m_pLetters['']=abyRUSEPixels;
	m_pLetters['']=abyRUSYOPixels;
	m_pLetters['']=abyRUSJPixels;
	m_pLetters['']=abyRUSZPixels;
	m_pLetters['']=abyRUSIPixels;
	m_pLetters['']=abyRUSIYPixels;
	m_pLetters['']=abyRUSKPixels;
	m_pLetters['']=abyRUSLPixels;
	m_pLetters['']=abyRUSMPixels;
	m_pLetters['']=abyRUSNPixels;
	m_pLetters['']=abyRUSOPixels;
	m_pLetters['']=abyRUSPPixels;
	m_pLetters['']=abyRUSRPixels;
	m_pLetters['']=abyRUSSPixels;
	m_pLetters['']=abyRUSTPixels;
	m_pLetters['']=abyRUSUPixels;
	m_pLetters['']=abyRUSFPixels;
	m_pLetters['']=abyRUSHPixels;
	m_pLetters['']=abyRUSCPixels;
	m_pLetters['']=abyRUSCHPixels;
	m_pLetters['']=abyRUSSHPixels;
	m_pLetters['']=abyRUSSHJPixels;
	m_pLetters['']=abyRUSTVZNPixels;
	m_pLetters['']=abyRUSbIPixels;
	m_pLetters['']=abyRUSMZNPixels;
	m_pLetters['']=abyRUSE2Pixels;
	m_pLetters['']=abyRUSYUPixels;
	m_pLetters['']=abyRUSYAPixels;


	//Russian
	m_pLetters['']=abyRUSaPixels;
	m_pLetters['']=abyRUSbPixels;
	m_pLetters['']=abyRUSvPixels;
	m_pLetters['']=abyRUSgPixels;
	m_pLetters['']=abyRUSdPixels;
	m_pLetters['']=abyRUSePixels;
	m_pLetters['']=abyRUSyoPixels;
	m_pLetters['']=abyRUSjPixels;
	m_pLetters['']=abyRUSzPixels;
	m_pLetters['']=abyRUSiPixels;
	m_pLetters['']=abyRUSiyPixels;
	m_pLetters['']=abyRUSkPixels;
	m_pLetters['']=abyRUSlPixels;
	m_pLetters['']=abyRUSmPixels;
	m_pLetters['']=abyRUSnPixels;
	m_pLetters['']=abyRUSoPixels;
	m_pLetters['']=abyRUSpPixels;
	m_pLetters['']=abyRUSrPixels;
	m_pLetters['']=abyRUSsPixels;
	m_pLetters['']=abyRUStPixels;
	m_pLetters['']=abyRUSuPixels;
	m_pLetters['']=abyRUSfPixels;
	m_pLetters['']=abyRUShPixels;
	m_pLetters['']=abyRUScPixels;
	m_pLetters['']=abyRUSchPixels;
	m_pLetters['']=abyRUSshPixels;
	m_pLetters['']=abyRUSshjPixels;
	m_pLetters['']=abyRUStvznPixels;
	m_pLetters['']=abyRUSbiPixels;
	m_pLetters['']=abyRUSmznPixels;
	m_pLetters['']=abyRUSe2Pixels;
	m_pLetters['']=abyRUSyuPixels;
	m_pLetters['']=abyRUSyaPixels;

	// 
	m_pLetters['.']=abyPointPixels;
	m_pLetters[',']=abyCommaPixels;
	m_pLetters[';']=abySemicolonPixels;
	m_pLetters[':']=abyColonPixels;
	m_pLetters['-']=abyDashPixels;
	m_pLetters['`']=abyApostrophePixels;
	m_pLetters['<']=abyLessPixels;
	m_pLetters['>']=abyGreaterPixels;
	m_pLetters['=']=abyEqualPixels;

	m_pLetters['+']=abyPlusPixels;
	m_pLetters['*']=abyMultiplyPixels;
	m_pLetters['/']=abyDividerPixels;

	//
	m_pLetters['0']=abyZeroPixels;
	m_pLetters['1']=abyOnePixels;
	m_pLetters['2']=abyTwoPixels;
	m_pLetters['3']=abyThreePixels;
	m_pLetters['4']=abyFourPixels;
	m_pLetters['5']=abyFivePixels;
	m_pLetters['6']=abySixPixels;
	m_pLetters['7']=abySevenPixels;
	m_pLetters['8']=abyEightPixels;
	m_pLetters['9']=abyNinePixels;
}


void  CGL::MainLoop(void)
{
	glutMainLoop();
}

void CGL::OnIdle()
{
	glutPostRedisplay();
}

void CGL::InitOpenGL(char * WindowTitle, int *argc,char *argv[])
{
	glutInit(argc,argv);
	glutInitDisplayMode(GLUT_MULTISAMPLE| GLUT_DOUBLE | GLUT_RGBA | GLUT_DEPTH |GLUT_STENCIL);
	
	glEnable(GLUT_MULTISAMPLE);
	glutCreateWindow(WindowTitle);
	glutDisplayFunc(Render);
	glutReshapeFunc(OnResize);
	glutSpecialFunc(OnSpecialKey);
	//glutIdleFunc(OnIdle);
	glutKeyboardFunc(OnKeyboard);
	glutTimerFunc(m_nTimerDelay,OnTimer,0);
	glutMouseFunc(OnMouse);
	glEnable(GL_DEPTH_TEST);
	glEnable(GL_LIGHTING);
	glEnableClientState(GL_COLOR_ARRAY);
	glEnableClientState(GL_VERTEX_ARRAY);
	glEnableClientState(GL_NORMAL_ARRAY);
	glEnable(GL_CULL_FACE);
	glEnable(GL_COLOR_MATERIAL);
	//glPolygonMode(GL_FRONT,GL_LINE);
	InitFont();
}