// gleditbox.cpp: implementation of the CGLEditBox class.
//
//////////////////////////////////////////////////////////////////////

#include "gleditbox.h"
#include "glstdafx.h"
//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////
#define z -1.0

CGLEditBox::CGLEditBox(GLfloat p_fx,GLfloat p_fy,
	GLfloat p_fWidth,GLfloat p_fHeight,
	const string& p_strText,GLint p_nEnterTextMaxLength,
	PFNONENDEDITPROC * p_pfnOnEndEdit)
	:CGLLabel(p_fx,p_fy,p_fWidth,p_fHeight,
	 p_strText)
{
	m_strEnterText=new char[p_nEnterTextMaxLength];
	m_strEnterText[0]=0;
	m_nEnterTextMaxLength=p_nEnterTextMaxLength;
	m_nEnterTextCurrentLength=0;
	m_pfnOnEndEdit=p_pfnOnEndEdit;
}


void CGLEditBox::Draw()
{

	GLint nTextLength=m_strText.length();
	GLfloat fSM=CGL::GetLetterSize();
	GLfloat fTextX=m_fx+fSM,fTextY=m_fy-m_fHeight+2*fSM,fTextWidth=m_fWidth-fSM*2,fTextHeight=fSM;
	GLfloat fLastColor[4];
	glGetFloatv(GL_CURRENT_COLOR,fLastColor);

	glBegin(GL_QUADS);		
		glVertex3f(m_fx+m_fWidth,m_fy-m_fHeight,z);
		glVertex3f(m_fx+m_fWidth,m_fy-fSM,z);
		glVertex3f(m_fx,m_fy-fSM,z);
		glVertex3f(m_fx,m_fy-m_fHeight,z);
	glEnd();


	glColor3f(0.0,0.0,0.0);
	glBegin(GL_QUADS);		
		glVertex3f(fTextX+fTextWidth,fTextY-fTextHeight,z);
		glVertex3f(fTextX+fTextWidth,fTextY,z);
		glVertex3f(fTextX,fTextY,z);
		glVertex3f(fTextX,fTextY-fTextHeight,z);
	glEnd();

	if (m_fHeight>5*fSM)
		CGL::DrawText(fTextX,m_fy-2*fSM,fTextWidth,m_fHeight-3*fSM,m_strText.c_str(),nTextLength);
	CGL::DrawText(fTextX,fTextY,fTextWidth,fTextHeight,m_strEnterText,m_nEnterTextCurrentLength);
}


void CGLEditBox::OnKeyboard(char p_chKey,GLint p_nx,GLint p_ny)
{
	switch (p_chKey)
	{
	case '\r'://return
		if (m_pfnOnEndEdit) m_pfnOnEndEdit(m_strEnterText);
		break;
	case '\b'://backspace
		if (m_nEnterTextCurrentLength>0)
		{
			m_nEnterTextCurrentLength--;
			m_strEnterText[m_nEnterTextCurrentLength]=0;
		}
		break;
	default:
		if (m_nEnterTextCurrentLength<=m_nEnterTextMaxLength)
		{
			m_strEnterText[m_nEnterTextCurrentLength]=p_chKey;
			m_nEnterTextCurrentLength++;
			m_strEnterText[m_nEnterTextCurrentLength]=0;
		}
		break;
	}
}	

void CGLEditBox::OnSpecialKey(GLint p_nKey,GLint p_nx,GLint p_ny)
{
	switch (p_nKey)
	{
	case GLUT_KEY_LEFT:
		if (m_nEnterTextCurrentLength>0)
		{
			m_nEnterTextCurrentLength--;
			m_strEnterText[m_nEnterTextCurrentLength]=0;
		}
		break;
	}
}

CGLEditBox::~CGLEditBox()
{
	delete [] m_strEnterText;
}
