// glframe.h: interface for the CGLFrame class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_GLFRAME_H__52C4444B_D042_4BB5_B413_D4E12DE0E4E1__INCLUDED_)
#define AFX_GLFRAME_H__52C4444B_D042_4BB5_B413_D4E12DE0E4E1__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
#include "importexport.h"
#include "glcolor.h"
#include "glvector3.h"


struct CGLVertex{
	CGLColor m_Color;
	CGLVector3 m_Normal;
	CGLVector3 m_Vertex;
};


class CGL_API  CGLFrame  
{
private:
	CGLVertex *m_Vertices;
	GLuint * m_unIndices;
	GLint m_nCountVertex;
	GLint m_nCountIndex;
	GLint m_nGraphQuality;
	GLfloat m_fShininess;
	CGLVector3 m_Parent;
public:
	CGLFrame(GLint p_nGraphQuality);


	void Draw(void){
		//glPushMatrix();
		glInterleavedArrays(GL_C4F_N3F_V3F,sizeof(CGLVertex),(GLfloat*)m_Vertices);
		//glDrawArrays(GL_POINTS,0,m_nCountVertex);
		//glDrawElements(GL_TRIANGLES,63,GL_UNSIGNED_INT,m_unIndices+63);
		//glDrawElements(GL_TRIANGLES,63 ,GL_UNSIGNED_INT,m_unIndices);
		GLfloat fLastShininess;
		glGetMaterialfv(GL_FRONT,GL_SHININESS,&fLastShininess);
		glMaterialf(GL_FRONT_AND_BACK,GL_SHININESS,m_fShininess);
		glDrawElements(GL_TRIANGLES,m_nCountIndex,GL_UNSIGNED_INT,m_unIndices);
		glMaterialf(GL_FRONT_AND_BACK,GL_SHININESS,fLastShininess);	
		//glPopMatrix();
	}
	void SetSphereChange(const CGLVector3 & p_rCenter,GLfloat p_fRadius)
	{
		SetSphereChange(p_rCenter.x,p_rCenter.y,p_rCenter.z,p_fRadius);
	}
	void SetSphereChange(GLfloat p_fx,GLfloat p_fy,GLfloat p_fz,GLfloat p_fRadius);

	void SetSphereColor(const CGLVector3& p_rCenter, GLfloat p_fRadius,CGLColor& p_Color)
	{
		SetSphereColor(p_rCenter.x,p_rCenter.y,p_rCenter.z,p_fRadius,p_Color);
	}
	void SetSphereColor(GLfloat p_fx,GLfloat p_fy, GLfloat p_fz,GLfloat p_fRadius,const CGLColor& p_Color);

	void SetLinearChange(const CGLVector3 & p_rStart, GLfloat p_fStartRadius,
		const CGLVector3 & p_rEnd,GLfloat p_fEndRadius)
	{
		SetLinearChange(p_rStart.x,p_rStart.y,p_rStart.z,p_fStartRadius,
			p_rEnd.x,p_rEnd.y,p_rEnd.z,p_fEndRadius);
	}
	void SetLinearChange(
		GLfloat p_fStartx,GLfloat p_fStarty,GLfloat p_fStartz,GLfloat p_fStartRadius,
		GLfloat p_fEndx,GLfloat p_fEndy,GLfloat p_fEndz,GLfloat p_fEndRadius);

	void SetLinearColor(const CGLVector3 & p_rStart, GLfloat p_fStartRadius,const CGLColor& p_StartColor,
		const CGLVector3 & p_rEnd,GLfloat p_fEndRadius,const CGLColor & p_EndColor)
	{
		SetLinearColor(p_rStart.x,p_rStart.y,p_rStart.z,p_fStartRadius,p_StartColor,
			p_rEnd.x,p_rEnd.y,p_rEnd.z,p_fEndRadius,p_EndColor);
	}
	void SetLinearColor(
		GLfloat p_fStartx,GLfloat p_fStarty,GLfloat p_fStartz,GLfloat p_fStartRadius,const CGLColor & p_StartColor,
		GLfloat p_fEndx,GLfloat p_fEndy,GLfloat p_fEndz,GLfloat p_fEndRadius,const CGLColor& p_EndColor);


	void SetParentPoint(const CGLVector3& p_rParent)
	{
		SetParentPoint(p_rParent.x,p_rParent.y,p_rParent.z);
	}

	void SetParentPoint(GLfloat p_fx, GLfloat p_fy,GLfloat p_fz);
	
	GLint GetGraphQuality(void) {return m_nGraphQuality;}

	GLint SetFileName(char * p_strFileName);

	const CGLVector3&  GetParentPoint(void);

	void SetShininess(GLfloat p_fShininess);
	
	GLfloat GetShininess(void);
	//    

	CGLVertex * GetVertices(void) {return m_Vertices;}
	int GetCountVertices(void) {return m_nCountVertex;}
	virtual ~CGLFrame();

};


#endif // !defined(AFX_GLFRAME_H__52C4444B_D042_4BB5_B413_D4E12DE0E4E1__INCLUDED_)
