// gllistbox.cpp: implementation of the CGLListBox class.
//
//////////////////////////////////////////////////////////////////////
#include "glstdafx.h"
#include "gllistbox.h"

#define z -1.0
//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CGLListBox::CGLListBox(GLfloat p_fx,GLfloat p_fy,
	GLfloat p_fWidth,GLfloat p_fHeight,
	const string& p_strText,PFNONENDCHOOSE *p_pfnOnEndChoose)
	:CGLLabel(p_fx,p_fy,p_fWidth,p_fHeight,p_strText)
{
	m_nCurrentScrollPosition=0;
	m_pfnOnEndChoose=p_pfnOnEndChoose;
	m_nSelectedItem=0;
	m_nHighlightSelection=0;
}

void CGLListBox::AddItem(const string& p_strItem)
{
	m_vctItems.push_back(p_strItem);

}
string CGLListBox::GetSelectedItem(void)
{
	if (m_vctItems.size()) 
		return m_vctItems[m_nSelectedItem];
	return string("");

}
int CGLListBox::GetSelectedItemIndex(void)
{
	if (m_vctItems.size())
		return m_nSelectedItem;
	return -1;
}

void CGLListBox::Draw(void)
{
	m_nHighlightSelection=(m_nHighlightSelection+1)%2;
	GLint nTextLength=m_strText.length();
	GLint n;
	GLfloat fSM=CGL::GetLetterSize();

	GLfloat fTextX=m_fx+fSM,fTextY=m_fy-fSM*3,fTextWidth=m_fWidth-fSM*2,fTextHeight=m_fHeight-fSM*4;
	GLfloat fLastColor[4];
	glGetFloatv(GL_CURRENT_COLOR,fLastColor);
	CGLControl::Draw();
	glColor3f(0.0,0.0,0.0);
	glBegin(GL_QUADS);		
		glVertex3f(fTextX+fTextWidth,fTextY-fTextHeight,z);
		glVertex3f(fTextX+fTextWidth,fTextY,z);
		glVertex3f(fTextX,fTextY,z);
		glVertex3f(fTextX,fTextY-fTextHeight,z);
	glEnd();

	CGL::DrawText(fTextX,m_fy-fSM,fTextWidth,0,m_strText.data(),nTextLength);
	glRasterPos4f(m_fx+m_fWidth-fSM,fTextY-fSM,-1.0,1.0f);
	glDrawPixels(8,8,GL_GREEN,GL_UNSIGNED_BYTE,(const GLvoid *)(g_abyUpPixels));
	glRasterPos4f(m_fx+m_fWidth-fSM,m_fy-m_fHeight,-1.0,1.0f);
	glDrawPixels(8,8,GL_GREEN,GL_UNSIGNED_BYTE,(const GLvoid *)(g_abyDownPixels));
	glColor4fv(fLastColor);
	if (m_vctItems.size())
	{
		for (n=m_nCurrentScrollPosition;n<m_vctItems.size();n++)
		{
			if ((m_nSelectedItem!=n)||(m_nHighlightSelection))
				CGL::DrawText(fTextX,fTextY-fSM*(n-m_nCurrentScrollPosition),
					fTextWidth,fTextHeight,m_vctItems[n].data(),m_vctItems[n].length());
		
		}
	}
}


void CGLListBox::OnMouse(GLint p_nButton,GLint p_nState,GLfloat p_fx,GLfloat p_fy)
{
	if (p_nState==GLUT_DOWN)
	{
		GLfloat fSM=CGL::GetLetterSize();
		GLfloat fRight=m_fx+m_fWidth,fTop=m_fy-fSM*3,
		fLeft=fRight-fSM,fBottom=fTop-fSM;
		GLfloat fTextX=m_fx+fSM,fTextY=m_fy-fSM*3,fTextWidth=m_fWidth-fSM*2,fTextHeight=m_fHeight-fSM*4;
		if ((fLeft<=p_fx)&&(fTop>=p_fy)&&(fRight>=p_fx)&&(fBottom<=p_fy))
		{
			if (m_nCurrentScrollPosition>0)m_nCurrentScrollPosition--;
		}
		fBottom=m_fy-m_fHeight;
		fTop=fBottom+fSM;
		if (m_nCurrentScrollPosition<m_vctItems.size()-1)
		{
			if ((fLeft<=p_fx)&&(fTop>=p_fy)&&(fRight>=p_fx)&&(fBottom<=p_fy))
			{
				m_nCurrentScrollPosition++;
			}
		}
		if ((p_fx>=fTextX)&&(p_fy>=fTextY-fTextHeight)&&(p_fx<=fTextX+fTextWidth)&&(p_fy<=fTextY))
		{
			GLfloat f=fTextY-p_fy;
			if (f>0)
			{
				GLint n=int(f/fSM);
				if (m_pfnOnEndChoose)
				{
					GLint nChoose=n+m_nCurrentScrollPosition;
					if (nChoose<m_vctItems.size())
					{
						m_nSelectedItem=nChoose;
						m_pfnOnEndChoose(m_vctItems[nChoose]);
					}
				}
			}
		}
	}
}

void CGLListBox::OnSpecialKey(GLint p_nKey,GLint p_nx,GLint p_ny)
{
	switch (p_nKey)
	{
	case GLUT_KEY_UP:
	case GLUT_KEY_PAGE_UP:
		if (m_nCurrentScrollPosition>0) m_nCurrentScrollPosition--;
		break;
	case GLUT_KEY_DOWN:
	case GLUT_KEY_PAGE_DOWN:
		if (m_nCurrentScrollPosition<m_vctItems.size()-1)m_nCurrentScrollPosition++;
		break;
	}
}

void CGLListBox::OnKeyboard(char p_chKey,GLint p_nx,GLint p_ny)
{
	switch (p_chKey)
	{
	case '\r':
		if (m_pfnOnEndChoose)
		{
			GLint nChoose=m_nCurrentScrollPosition;
			
			if (nChoose<m_vctItems.size())
			{
				m_nSelectedItem=nChoose;
				m_pfnOnEndChoose(m_vctItems[nChoose]);
			}
		}
		break;
	}
}
CGLListBox::~CGLListBox()
{

}
