// glslider.cpp: implementation of the CGLSlider class.
//
//////////////////////////////////////////////////////////////////////

#include "glstdafx.h"
#include "glslider.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////
const float z =-1.0;

CGLSlider::CGLSlider(GLfloat p_fx,GLfloat p_fy,
	GLfloat p_fWidth,GLfloat p_fHeight,
	const string& p_strText,	PFNONSLIDERPROC * p_pfnOnSlider)
	:CGLLabel(p_fx,p_fy,p_fWidth,p_fHeight,p_strText)
{
	m_pfnOnSlider=p_pfnOnSlider;
	m_fValue=1.0f;
}


void CGLSlider::SetValue(GLfloat p_fValue)
{
	if (p_fValue>1.0) p_fValue=1.0;
	else if (p_fValue<0.0) p_fValue=0.0;
	m_fValue=p_fValue;
}


void CGLSlider::Draw()
{
	GLfloat fSM=CGL::GetLetterSize()*2;
	GLfloat fPosWidth=CGL::GetLetterSize();
	GLfloat fPos=m_fValue*m_fWidth;
	CGLLabel::Draw();
	GLfloat fTop=m_fy-2*fSM;
	glBegin(GL_LINES);
		glVertex3f(m_fx,fTop,z);
		glVertex3f(m_fx+m_fWidth,fTop,z);
	glEnd();

	GLfloat fLeft=m_fx+fPos,fRight=fLeft+fPosWidth;
	static GLubyte abyCaretPixels[]={
		0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
		0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
		0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
		0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
		0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
		0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
		0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
		0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
	};
	glRasterPos4f(fLeft,fTop,-1.0,1.0f);
	glDrawPixels(8,8,GL_GREEN,GL_UNSIGNED_BYTE,(const GLvoid *)(abyCaretPixels));

}

void CGLSlider::OnMouse(GLint p_nButton,GLint p_nState,GLfloat p_fx,GLfloat p_fy)
{
	if ((m_fx<=p_fx)&&(m_fy>=p_fy)&&(m_fx+m_fWidth>=p_fx)&&(m_fy-m_fHeight<=p_fy))
	{
		SetValue((p_fx-m_fx)/(m_fWidth));
		if (m_pfnOnSlider) m_pfnOnSlider(m_fValue);
	}
}

void CGLSlider::OnSpecialKey(GLint p_nKey,GLint p_nx,GLint p_ny)
{
	switch (p_nKey)
	{
	case GLUT_KEY_RIGHT:
		SetValue(m_fValue+0.01);
		break;
	case GLUT_KEY_LEFT:
		SetValue(m_fValue-0.01);
		break;
	}
}	
	
CGLSlider::~CGLSlider()
{

}
