// 3dcursor.cpp: implementation of the C3DCursor class.
//
//////////////////////////////////////////////////////////////////////
#include "stdafx.h"
#include "3dcursor.h"

enum COMMAND{
	SPHERE_CHANGE,
	LINE_CHANGE,
	SPHERE_PAINT,
	LINE_PAINT,
	CONNECTION_POINTS,
	PARENT_POINT,
};
int g_nSphereChange=SPHERE_CHANGE,
	g_nLineChange=LINE_CHANGE,
	g_nSpherePaint=SPHERE_PAINT,
	g_nLinePaint=LINE_PAINT;
	

C3DCursor::C3DCursor(GLfloat p_fx,GLfloat p_fy, GLfloat p_fz, CGLFrame* p_pFrame)
{
	m_fx=p_fx; m_fy=p_fy; m_fz=p_fz;
	m_pFrame=p_pFrame;
	m_fRadius=0.4;
	m_fStep=0.1;
	m_of=0;
	m_ofmeta=0;
}

C3DCursor::~C3DCursor()
{
	//puts("destructor");
	if (m_of)
	{
		if (m_vctConnectionPoints.size())
		{
			putw(CONNECTION_POINTS,m_of);
			CONNECTION_POINT_VECTOR::iterator iList=m_vctConnectionPoints.begin();
			int nHasParent=0;
			int n=m_vctConnectionPoints.size();
			fwrite((const void*) &n,sizeof(n),1,m_of);
			while(iList!=m_vctConnectionPoints.end())
			{
				fwrite((const void*)&(*iList),sizeof(CConnectionPoint),1,m_of);
				iList++;
			}
		}
		putw(PARENT_POINT,m_of);
		CGLVector3 parent(m_fParentx,m_fParenty,m_fParentz);
		fwrite((const void*)&parent,sizeof(CGLVector3),1,m_of);
		fclose(m_of);
	}
	if (m_ofmeta)
	{

		//if ()
		//GLfloat fShininess=0;
		//if (m_pFrame) fShininess=m_pFrame->GetShininess();
		//fwrite((const void*)&fShininess,sizeof(fShininess),1,m_ofmeta);
		fclose(m_ofmeta);
	}

}

void C3DCursor::SetEndPoint()
{
	int nCommand;
	switch (m_nMode)
	{
	case MODE_CONSTRUCT:
		m_pFrame->SetLinearChange(m_fStartx,m_fStarty,m_fStartz,m_fStartRadius,
		m_fx,m_fy,m_fz,m_fRadius);
		nCommand=LINE_CHANGE;
		if (m_of)
		{
			fwrite((const void *)&nCommand,sizeof(nCommand),1,m_of);
			fwrite((const void *)&m_fStartx,sizeof(m_fStartx),1,m_of);
			fwrite((const void *)&m_fStarty,sizeof(m_fStarty),1,m_of);
			fwrite((const void *)&m_fStartz,sizeof(m_fStartz),1,m_of);
			fwrite((const void *)&m_fStartRadius,sizeof(m_fStartRadius),1,m_of);

			fwrite((const void *)&m_fx,sizeof(m_fx),1,m_of);
			fwrite((const void *)&m_fy,sizeof(m_fy),1,m_of);
			fwrite((const void *)&m_fz,sizeof(m_fz),1,m_of);
			fwrite((const void *)&m_fRadius,sizeof(m_fRadius),1,m_of);
		}
		break;
	case MODE_PAINT:
		nCommand=LINE_PAINT;
		m_pFrame->SetLinearColor(m_fStartx,
			m_fStarty,
			m_fStartz,
			m_fStartRadius,
			m_StartColor,
		m_fx,
		m_fy,
		m_fz,
		m_fRadius,
		m_Color);
		if (m_of)
		{
			fwrite((const void *)&nCommand,sizeof(nCommand),1,m_of);
			fwrite((const void *)&m_fStartx,sizeof(m_fStartx),1,m_of);
			fwrite((const void *)&m_fStarty,sizeof(m_fStarty),1,m_of);
			fwrite((const void *)&m_fStartz,sizeof(m_fStartz),1,m_of);
			fwrite((const void *)&m_fStartRadius,sizeof(m_fStartRadius),1,m_of);
			fwrite((const void *)&m_StartColor,sizeof(m_StartColor),1,m_of);

			fwrite((const void *)&m_fx,sizeof(m_fx),1,m_of);
			fwrite((const void *)&m_fy,sizeof(m_fy),1,m_of);
			fwrite((const void *)&m_fz,sizeof(m_fz),1,m_of);
			fwrite((const void *) &m_fRadius,sizeof(m_fRadius),1,m_of);
			fwrite((const void *)&m_Color,sizeof(m_Color),1,m_of);
		}
		break;
	}
	if (m_of)
	{
		if (ferror(m_of))  throw 1;
	}

}

void C3DCursor::SetStartPoint()
{
	m_fStartx=m_fx; m_fStarty=m_fy; m_fStartz=m_fz;m_fStartRadius=m_fRadius;
	m_StartColor=m_Color;
}

void C3DCursor::SetSphereChange()
{
	int nCommand;
	switch (m_nMode)
	{
	case MODE_PAINT:
		nCommand=SPHERE_PAINT;
		m_pFrame->SetSphereColor(m_fx,m_fy,m_fz,m_fRadius,m_Color);
		if (m_of)
		{
			fwrite((const void *)&nCommand,sizeof(nCommand),1,m_of);
			fwrite((const void *)&m_fx,sizeof(m_fx),1,m_of);
			fwrite((const void *)&m_fy,sizeof(m_fy),1,m_of);
			fwrite((const void *)&m_fz,sizeof(m_fz),1,m_of);
			fwrite((const void *)&m_fRadius,sizeof(m_fRadius),1,m_of);
			fwrite((const void *)&m_Color,sizeof(m_Color),1,m_of);
		}
		break;
	case MODE_CONSTRUCT:
		nCommand=SPHERE_CHANGE;
		m_pFrame->SetSphereChange(m_fx,m_fy,m_fz,m_fRadius);
		if (m_of)
		{
			fwrite((const void *)&nCommand,sizeof(nCommand),1,m_of);
			fwrite((const void *)&m_fx,sizeof(m_fx),1,m_of);
			fwrite((const void *)&m_fy,sizeof(m_fy),1,m_of);
			fwrite((const void *)&m_fz,sizeof(m_fz),1,m_of);
			fwrite((const void *)&m_fRadius,sizeof(m_fRadius),1,m_of);
		}
		break;
	}
	if (m_of)
	{
		if (ferror(m_of))
		{
			perror(m_strOutputFileName);
			throw 1;
		}

	}

}

int C3DCursor::LoadCommandsFromFile(const char * p_strFileName)
{
	FILE *file=fopen(p_strFileName,"r");
	if (!file) return 0;
	int nBaseFileNameLength=getw(file);
	if (nBaseFileNameLength)
	{
		char *s=new char[nBaseFileNameLength+1];
		fread((void*)s,nBaseFileNameLength,1,file);
		s[nBaseFileNameLength]=0;
		LoadCommandsFromFile(s);
		delete [] s;
	}
	int command;
	while ((!ferror(file))&&(!feof(file)))
	{
		fread((void *)&command,sizeof(command),1,file);
		if (feof(file)) break;

		switch (command)
		{
		case SPHERE_CHANGE:
			m_nMode=MODE_CONSTRUCT;
			fread((void *)&m_fx,sizeof(m_fx),1,file);
			fread((void *)&m_fy,sizeof(m_fy),1,file);
			fread((void *)&m_fz,sizeof(m_fz),1,file);
			fread((void *)&m_fRadius,sizeof(m_fRadius),1,file);
			SetSphereChange();
			break;
		case SPHERE_PAINT:
			m_nMode=MODE_PAINT;
			fread((void *)&m_fx,sizeof(m_fx),1,file);
			fread((void *)&m_fy,sizeof(m_fy),1,file);
			fread((void *)&m_fz,sizeof(m_fz),1,file);
			fread((void *)&m_fRadius,sizeof(m_fRadius),1,file);
			fread((void *)&m_Color,sizeof(m_Color),1,file);
			SetSphereChange();
			break;
		case LINE_CHANGE:
			m_nMode=MODE_CONSTRUCT;
			fread((void *)&m_fx,sizeof(m_fx),1,file);
			fread((void *)&m_fy,sizeof(m_fy),1,file);
			fread((void *)&m_fz,sizeof(m_fz),1,file);
			fread((void *)&m_fRadius,sizeof(m_fRadius),1,file);
			SetStartPoint();
			fread((void *)&m_fx,sizeof(m_fx),1,file);
			fread((void *)&m_fy,sizeof(m_fy),1,file);
			fread((void *)&m_fz,sizeof(m_fz),1,file);
			fread((void *)&m_fRadius,sizeof(m_fRadius),1,file);
			SetEndPoint();
			break;
		case LINE_PAINT:
			m_nMode=MODE_PAINT;
			fread((void *)&m_fx,sizeof(m_fx),1,file);
			fread((void *)&m_fy,sizeof(m_fy),1,file);
			fread((void *)&m_fz,sizeof(m_fz),1,file);
			fread((void *)&m_fRadius,sizeof(m_fRadius),1,file);
			fread((void *)&m_Color,sizeof(m_Color),1,file);
			SetStartPoint();
			fread((void *)&m_fx,sizeof(m_fx),1,file);
			fread((void *)&m_fy,sizeof(m_fy),1,file);
			fread((void *)&m_fz,sizeof(m_fz),1,file);
			fread((void *)&m_fRadius,sizeof(m_fRadius),1,file);
			fread((void *)&m_Color,sizeof(m_Color),1,file);
			SetEndPoint();
			break;
		case CONNECTION_POINTS:
			{
			int n;
			CConnectionPoint pt;
			fread((void*)&n,sizeof(n),1,file);
			for (int m_nCountConnectionPoints=0;
			m_nCountConnectionPoints<n;m_nCountConnectionPoints++)
			{
				fread((void*)&pt,sizeof(pt),1,file);
				m_vctConnectionPoints.push_back(pt);
			}
			break;
			}
		case PARENT_POINT:
			{
			CGLVector3 parent;
			fread((void*)&parent,sizeof(parent),1,file);
			m_pFrame->SetParentPoint(parent);
			break;
			}
		}
	}
		fclose(file);
	if (ferror(file))
		return 0;
	else
		return 1;
}


void C3DCursor::Draw(void)
{
	glPushMatrix();
	glTranslatef(m_fx,m_fy,m_fz);
	glColor4fv((GLfloat*)&m_Color);
	glutWireSphere(m_fRadius ,10,10);
	glPopMatrix();
	if (m_pFrame)
	{
		glPushMatrix();
		glColor3f(1.0,0.0,0.0);
		
		glBegin(GL_LINES);
		  glVertex3f(-1000.0,m_fParenty,m_fParentz);
		  glVertex3f(1000.0,m_fParenty,m_fParentz);
		  glVertex3f(m_fParentx,-1000.0,m_fParentz);
		  glVertex3f(m_fParentx,1000.0,m_fParentz);
		  glVertex3f(m_fParentx,m_fParenty,-1000.0);
		  glVertex3f(m_fParentx,m_fParenty,1000.0);
		glEnd();
		glPopMatrix();
	}

}

void C3DCursor::SetParentPoint(void)
{
	m_fParentx=m_fx;
	m_fParenty=m_fy;
	m_fParentz=m_fz;
}


void C3DCursor::AddConnectionPoint(int p_nNumber)
{
	CConnectionPoint pt;
	pt.m_nNumber=p_nNumber;
	pt.m_fx =m_fx;
	pt.m_fy=m_fy;
	pt.m_fz=m_fz;
	m_vctConnectionPoints.push_back(pt);
}

void C3DCursor::SetConnectionPoint(int p_nIndex, const CConnectionPoint& p_pt)
{
	m_vctConnectionPoints.at(p_nIndex)=p_pt;
}

void C3DCursor::RemoveConnectionPoint(int p_nIndex)
{
	m_vctConnectionPoints.erase(&m_vctConnectionPoints.at(p_nIndex));
}

int C3DCursor::GetConnectionPointsCount(void)
{
	return m_vctConnectionPoints.size();
}

const CConnectionPoint& C3DCursor::GetConnectionPoint(int p_nIndex)
{
	return m_vctConnectionPoints.at(p_nIndex);
}

void C3DCursor::SetFrame(CGLFrame * p_pFrame)
{
	
		m_pFrame=p_pFrame;


}

int C3DCursor::SetOutputFileName(char *p_strBaseFileName,char *p_strOutputFileName) 
{
	m_of=fopen(p_strOutputFileName,"w");
	string strMetaFileName=p_strOutputFileName;
	strMetaFileName+=".meta";
	m_ofmeta=fopen(strMetaFileName.c_str(),"w");
	//setvbuf( m_of, NULL, _IONBF, 0 );
	if (strcmp(p_strBaseFileName,"")==0)
	{
		putw(0,m_of);
	}
	else
	{
		putw(strlen(p_strBaseFileName),m_of);
		fwrite(p_strBaseFileName,strlen(p_strBaseFileName),1,m_of);
		LoadCommandsFromFile(p_strBaseFileName);

	}

		if (m_of) return 1;
	else if (ferror (m_of))return 0;
	return 0;
}


void C3DCursor::SetShininess(GLfloat p_fShininess)
{
	if (m_pFrame) m_pFrame->SetShininess(p_fShininess);
	else throw 1;
}

GLfloat C3DCursor::GetShininess(void)
{
	if (m_pFrame) return m_pFrame->GetShininess();
	else throw 1;
}